<?php
/**
 * Tabber widget
 *
 * @package VolThemes Widget Pack
 * @version 1.0
 */

/**
 * Adds vt_blogging_pro_tab_widget widget.
 */
add_action( 'widgets_init', create_function( '', 'register_widget( "vt_blogging_pro_tab_widget" );' ) );
class vt_blogging_pro_tab_widget extends WP_Widget {
		
	/**
	 * Register widget with WordPress.
	 */
	public function __construct() {
		
		// Create the widget.
		parent::__construct(
	 		'vt-blogging-pro-tab-widget',
			'[VT] Tabs Widget',
			array(
				'classname'   => 'vt-tabs-widget widget_tabs widget_posts_thumbnail',
				'description'	=> __( 'Display a tabbed content widget for your popular posts, recent posts and popular tags.', 'vt-blogging-pro' )
			)
		);
		
	}

	/**
	 * Helper function that holds widget fields
	 * Array is used in update and form functions
	 */
	 private function widget_fields() {
		$fields = array(
			// Other fields
			'tabs_post_count' => array (
				'volthemes_widgets_name'			=> 'tabs_post_count',
				'volthemes_widgets_title'			=> __( 'Posts to Show', 'vt-blogging-pro' ),
				'volthemes_widgets_field_type'		=> 'text'
			),
			'tabs_tag_count' => array (
				'volthemes_widgets_name'			=> 'tabs_tag_count',
				'volthemes_widgets_title'			=> __( 'Tags to Show', 'vt-blogging-pro' ),
				'volthemes_widgets_field_type'		=> 'text'
			),
		);
		
		return $fields;
	 }

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		extract( $args );
		
		$tabs_post_count	= $instance['tabs_post_count'];
		$tabs_tag_count		= $instance['tabs_tag_count'];

		echo $before_widget;
		?>

		<ul id="widget-tab" class="clearfix widget-tab-nav">
			<li class="active"><a href="#widget-tab-popular"><?php _e( 'Popular', 'vt-blogging-pro' ); ?></a></li>
			<li><a href="#widget-tab-latest"><?php _e('Latest', 'vt-blogging-pro' ); ?></a></li>
			<li><a href="#widget-tab-tags"><?php _e( 'Tags', 'vt-blogging-pro' ); ?></a></li>
		</ul>
 
		<div class="widget-tab-content">
			<div class="tab-pane active" id="widget-tab-popular">
				<ul>
				<?php $popular = new WP_Query('orderby=comment_count&ignore_sticky_posts=1&posts_per_page=' . $tabs_post_count );
					while ($popular->have_posts()) : $popular->the_post(); ?>								
					<li class="clearfix">
						<?php if ( has_post_thumbnail() ) { ?>
						<div class="thumbnail-wrap">
							<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"><?php the_post_thumbnail( 'vt_blogging_pro_widget', array( 'title' => get_the_title() ) ); ?></a>
						</div>
						<div class="entry-wrap">
							<h4><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" rel="bookmark"><?php the_title(); ?></a></h4>
							<div class="entry-meta"><?php comments_number( __( 'No Comments', 'vt-blogging-pro' ), __( '1 Comment', 'vt-blogging-pro' ), __( '% Comments', 'vt-blogging-pro' ) ); ?></div>
						</div>
						<?php } else { ?>
						<div class="thumbnail-wrap">
							<img src="<?php echo esc_url( get_template_directory_uri() ); ?>/assets/img/no-thumbnail.png" alt="<?php esc_attr__('No Picture', 'vt-blogging-pro');?>" />
						</div>
						<div class="entry-wrap">
							<h4><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" rel="bookmark"><?php the_title(); ?></a></h4>
							<div class="entry-meta"><?php comments_number( __( 'No Comments', 'vt-blogging-pro' ), __( '1 Comment', 'vt-blogging-pro' ), __( '% Comments', 'vt-blogging-pro' ) ); ?></div>
						</div>
						<?php } ?>
					</li>
				<?php endwhile; wp_reset_postdata(); ?>
				</ul>
			</div><!-- #widget-tab-popular -->

			<div class="tab-pane" id="widget-tab-latest">
				<ul>
					<?php $latest = new WP_Query('orderby=post_date&order=DESC&ignore_sticky_posts=1&posts_per_page=' . $tabs_post_count );
					while ( $latest -> have_posts() ) : $latest -> the_post(); ?>
					<li class="clearfix">
						<?php if ( has_post_thumbnail() ) { ?>
						<div class="thumbnail-wrap">
							<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"><?php the_post_thumbnail( 'vt_blogging_pro_widget', array( 'title' => get_the_title() ) ); ?></a>
						</div>
						<div class="entry-wrap">
							<h4><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" rel="bookmark"><?php the_title(); ?></a></h4>
							<div class="entry-meta"><?php the_time('F d, Y'); ?></div>
						</div>							
						<?php } else { ?>
						<div class="thumbnail-wrap">
							<img src="<?php echo esc_url( get_template_directory_uri() ); ?>/assets/img/no-thumbnail.png" alt="<?php esc_attr__('No Picture', 'vt-blogging-pro');?>" />
						</div>
						<div class="entry-wrap">
							<h4><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" rel="bookmark"><?php the_title(); ?></a></h4>
							<div class="entry-meta"><?php the_time('F d, Y'); ?></div>
						</div>							
						<?php } ?>
					</li>
					<?php endwhile; wp_reset_postdata(); ?>
				</ul>
			</div><!-- #widget-tab-latest -->

			<div class="tab-pane tagcloud" id="widget-tab-tags">
				<?php wp_tag_cloud('smallest=1&largest=1.6&unit=em&orderby=count&order=DESC&number=' . $tabs_tag_count ); ?>
			</div><!-- #widget-tab-tags -->
		</div>

	<?php
		echo $after_widget;
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param	array	$new_instance	Values just sent to be saved.
	 * @param	array	$old_instance	Previously saved values from database.
	 *
	 * @uses	volthemes_widgets_show_widget_field() defined in widget-fields.php
	 *
	 * @return	array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$widget_fields = $this->widget_fields();

		// Loop through fields
		foreach( $widget_fields as $widget_field ) {
			extract( $widget_field );
	
			// Use helper function to get updated field values
			$instance[$volthemes_widgets_name] = volthemes_widgets_updated_field_value( $widget_field, $new_instance[$volthemes_widgets_name] );
			echo $instance[$volthemes_widgets_name];
		}
				
		return $instance;
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 *
	 * @uses volthemes_widgets_show_widget_field() defined in widget-fields.php
	 */
	public function form( $instance ) {
		$widget_fields = $this->widget_fields();

		// Loop through fields
		foreach( $widget_fields as $widget_field ) {
		
			// Make array elements available as variables
			extract( $widget_field );
			$volthemes_widgets_field_value = isset( $instance[$volthemes_widgets_name] ) ? esc_attr( $instance[$volthemes_widgets_name] ) : '';
			volthemes_widgets_show_widget_field( $this, $widget_field, $volthemes_widgets_field_value );
		
		}	
	}

} // class vt_blogging_pro_tab_widget
?>